@@ -10,7 +10,7 @@ from typing import List, Optional, Dict, Any, Tuple, Union, Callable, TYPE_CHECK
 import pytest
 from pyspark.sql import SparkSession, DataFrame
 from pyspark.sql.catalog import Table
-from pyspark.sql.types import StructType
+from pyspark.sql.types import StructType, DataType
 from spark_data_frame_comparer.spark_data_frame_comparer import (
     assert_compare_data_frames,
 )
@@ -32,7 +32,7 @@ from spark_pipeline_framework_testing.mockserver_client.exceptions.mock_server_r
 from spark_pipeline_framework_testing.mockserver_client.mockserver_client import (
     MockServerFriendlyClient,
 )
-from spark_pipeline_framework_testing.utils.path_converter import (
+from spark_pipeline_framework_testing.tests_common.path_converter import (
     convert_path_from_docker,
 )
 from spark_pipeline_framework_testing.mockserver_client.mockserver_verify_exception import (
@@ -232,11 +232,12 @@ class MockCallValidator(Validator):
 
 class OutputFileValidator(Validator):
     """
-    compare files
+    compare input and output files
     """
 
     def __init__(
         self,
+        related_inputs: Union[List["FileInput"], "FileInput"],
         func_path_modifier: Optional[
             Callable[[Union[Path, str]], Union[Path, str]]
         ] = None,
@@ -247,8 +248,19 @@ class OutputFileValidator(Validator):
         output_folder: str = "output",
         output_schema_folder: str = "output_schema",
         output_schema: Optional[Union[StructType, Dict[str, StructType]]] = None,
-        related_inputs: Optional[Union[List["FileInput"], "FileInput"]] = None,
     ):
+        """
+
+        :param related_inputs: the corresponding input for this validator
+        :param func_path_modifier: in case you want to change paths e.g. docker to local
+        :param sort_output_by: order of column names [col1, col2,...]
+        :param output_as_json_only: save output as json
+        :param apply_schema_to_output:
+        :param ignore_views_for_output: don't save these views
+        :param output_folder: name of the output folder
+        :param output_schema_folder: name of the folder containing output schema
+        :param output_schema: the schema of the output (overwrites output_schema_folder)
+        """
         self.func_path_modifier = func_path_modifier
         self.sort_output_by = sort_output_by
         self.output_as_json_only = output_as_json_only
@@ -374,7 +386,7 @@ class OutputFileValidator(Validator):
         func_path_modifier: Optional[Callable[[Union[Path, str]], Union[Path, str]]],
         sort_output_by: Optional[List[str]],
         apply_schema_to_output: bool,
-        output_schema: Optional[Union[StructType, Dict[str, StructType]]],
+        output_schema: Optional[Union[StructType, Dict[str, StructType], DataType]],
     ) -> Tuple[bool, Optional[SparkDataFrameComparerException]]:
         """
         read predefined outputs and compare them with the current outputs
